<p align="center"><strong>SQLFMT</strong> - <em>An uncompromising SQL query formatter.</em></p>

<p align="center">
    <a href="https://pypi.org/project/sqlfmt/"><img alt="PyPI Latest Release" src="https://img.shields.io/pypi/v/sqlfmt.svg"></a>
    <a href="https://pypi.org/project/sqlfmt/"><img alt="Package Status" src="https://img.shields.io/pypi/status/sqlfmt.svg"></a>
    <a href="https://github.com/psf/black/"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
    <a href="https://pycqa.github.io/isort/"><img alt="Imports: isort" src="https://img.shields.io/badge/%20imports-isort-%231674b1"></a>
</p>

Please note that the `sqlfmt` project is still in the planning stage and interfaces may be changed in the future.

## Setup

### Installation

Install `sqlfmt` from [Python Package Index](https://pypi.org/project/sqlfmt/):

```
pip install sqlfmt
```

Install `sqlfmt` from [Source Code](https://github.com/HH-MWB/sqlfmt):

```
python setup.py install
```
